diff sat/plugins/plugin_xep_0297.py @ 4037:524856bd7b19

massive refactoring to switch from camelCase to snake_case: historically, Libervia (SàT before) was using camelCase as allowed by PEP8 when using a pre-PEP8 code, to use the same coding style as in Twisted. However, snake_case is more readable and it's better to follow PEP8 best practices, so it has been decided to move on full snake_case. Because Libervia has a huge codebase, this ended with a ugly mix of camelCase and snake_case. To fix that, this patch does a big refactoring by renaming every function and method (including bridge) that are not coming from Twisted or Wokkel, to use fully snake_case. This is a massive change, and may result in some bugs.
author Goffi <goffi@goffi.org>
date Sat, 08 Apr 2023 13:54:42 +0200
parents 944f51f9c2b4
children
line wrap: on
line diff
--- a/sat/plugins/plugin_xep_0297.py	Fri Apr 07 15:18:39 2023 +0200
+++ b/sat/plugins/plugin_xep_0297.py	Sat Apr 08 13:54:42 2023 +0200
@@ -54,11 +54,11 @@
         log.info(_("Stanza Forwarding plugin initialization"))
         self.host = host
 
-    def getHandler(self, client):
+    def get_handler(self, client):
         return XEP_0297_handler(self, client.profile)
 
     @classmethod
-    def updateUri(cls, element, uri):
+    def update_uri(cls, element, uri):
         """Update recursively the element URI.
 
         @param element (domish.Element): element to update
@@ -70,7 +70,7 @@
         element.defaultUri = uri
         for child in element.children:
             if isinstance(child, domish.Element) and not child.uri:
-                XEP_0297.updateUri(child, uri)
+                XEP_0297.update_uri(child, uri)
 
     def forward(self, stanza, to_jid, stamp, body="", profile_key=C.PROF_KEY_NONE):
         """Forward a message to the given JID.
@@ -82,7 +82,7 @@
         @param profile_key (unicode): %(doc_profile_key)s
         @return: a Deferred when the message has been sent
         """
         # FIXME: this method is not used and doesn't use mess_data which should be used for client.sendMessageData
         #        should it be deprecated? A method constructing the element without sending it seems more natural
         log.warning(
             "THIS METHOD IS DEPRECATED"
@@ -99,14 +99,14 @@
         delay_elt = self.host.plugins["XEP-0203"].delay(stamp)
         forwarded_elt.addChild(delay_elt)
         if not stanza.uri:  # None or ''
-            XEP_0297.updateUri(stanza, "jabber:client")
+            XEP_0297.update_uri(stanza, "jabber:client")
         forwarded_elt.addChild(stanza)
 
         msg.addChild(body_elt)
         msg.addChild(forwarded_elt)
 
-        client = self.host.getClient(profile_key)
-        return defer.ensureDeferred(client.sendMessageData({"xml": msg}))
+        client = self.host.get_client(profile_key)
+        return defer.ensureDeferred(client.send_message_data({"xml": msg}))
 
 
 @implementer(iwokkel.IDisco)
@@ -82,7 +82,7 @@
         @return: a Deferred when the message has been sent
         """
-        # FIXME: this method is not used and doesn't use mess_data which should be used for client.sendMessageData
+        # FIXME: this method is not used and doesn't use mess_data which should be used for client.send_message_data
         #        should it be deprecated? A method constructing the element without sending it seems more natural
         log.warning(